*rst2slides* generates an HTML5 slideshow document from standalone 
reStructuredText_ source.

Usage
=====

::

  $ rst2slides slides.rst slides.html


Credits
=======

It uses Rob Flaherty's Lightweight `HTML5 Slideshow`_ as template, 
and the most of Bruno Renie's HTML5Translator_ . 


.. _reStructuredText: http://docutils.sourceforge.net/rst.html
.. _`HTML5 Slideshow`: http://www.ravelrumba.com/blog/html5-slideshow/
.. _HTML5Translator: https://gist.github.com/461392

